@@ -204,7 +204,7 @@ class Project(Model):
                         obj2.update(
                             times_seen=F('times_seen') + obj.times_seen,
                             time_spent_total=F('time_spent_total') + obj.time_spent_total,
-                            time_spent_count=F('times_seen') + obj.time_spent_count,
+                            time_spent_count=F('time_spent_count') + obj.time_spent_count,
                         )
 
         for fv in FilterValue.objects.filter(project=self):
@@ -245,7 +245,7 @@ class ProjectKey(Model):
             self.public_key,
             self.secret_key,
             urlparts.netloc + urlparts.path,
-            self.project_id,
+            self.project.slug,
         )
 
 
@@ -440,7 +440,7 @@ class Group(MessageBase):
 
     def get_absolute_url(self):
         if self.project_id:
-            return reverse('sentry-group', kwargs={'group_id': self.pk, 'project_id': self.project_id})
+            return reverse('sentry-group', kwargs={'group_id': self.pk, 'project_id': self.project.slug})
         return '#'
 
     def natural_key(self):
@@ -513,7 +513,7 @@ class Event(MessageBase):
 
     def get_absolute_url(self):
         if self.project_id:
-            return reverse('sentry-group-event', kwargs={'group_id': self.group_id, 'event_id': self.pk, 'project_id': self.project_id})
+            return reverse('sentry-group-event', kwargs={'group_id': self.group_id, 'event_id': self.pk, 'project_id': self.project.slug})
         return '#'
 
     @cached_property
@@ -749,22 +749,26 @@ def create_team_for_project(instance, created, **kwargs):
     if not created:
         return
 
-    if instance.team:
-        return
-
     if not instance.owner:
         return
 
-    update(instance, team=Team.objects.create(
-        owner=instance.owner,
-        name=instance.name,
-        slug=instance.slug,
-    ))
+    if not instance.team:
+        update(instance, team=Team.objects.create(
+            owner=instance.owner,
+            name=instance.name,
+            slug=instance.slug,
+        ))
 
-    ProjectKey.objects.get_or_create(
-        project=instance,
-        user=instance.owner,
-    )
+        ProjectKey.objects.get_or_create(
+            project=instance,
+            user=instance.owner,
+        )
+    else:
+        for member in instance.team.member_set.all():
+            ProjectKey.objects.get_or_create(
+                project=instance,
+                user=member.user,
+            )
 
 
 def create_team_member_for_owner(instance, created, **kwargs):
