@@ -202,7 +202,7 @@ class IPlugin(local):
 
         >>> plugin.get_url(group)
         """
-        return reverse('sentry-group-plugin-action', args=(group.project_id, group.pk, self.slug))
+        return reverse('sentry-group-plugin-action', args=(group.project.slug, group.pk, self.slug))
 
     def get_conf_key(self):
         """
